## Product details

Christmas Wreath Wreath for Front Door Farmhouse Housewarming Xmas Wreath Holiday Garland Decoration for Garden Festival Wall Diameter 35cm.Decorated with red berries, and green leaves, it has a realistic visual effect, keeping your house full of life.Xmas wreath is made of high quality material, brightly colored, durable, and requires no special cleaning or maintenance.It adds a festive touch to your home and the eye catching Christmas wreath will attract your guests.Holiday garland is perfect for decorating Christmas, Halloween, Thanksgiving, weddings, walls, doors, stages, bedrooms, offices, hotels, restaurants, gardens, balconies, fences, fireplaces, entryways, etc.A Christmas wreath makes a perfect gift for friends, family, neighbors, housewarmings, farmhouses, and other .Artificial Christmas Wreath Holiday Garland. Outside Xmas Wreath Front Door Wreath Wall. Wreath for Front Door Ornaments Dining Room. Holiday Garland Decoration Indoor Outdoor Hotel. Front Door Wreath Porch Wedding.
[High Quality Material]: Xmas wreath is made of high quality material, brightly colored, durable, and requires no special cleaning or maintenance.
[Front Door Wreath]: It adds a festive touch to your home and the eye catching Christmas wreath will attract your guests.
[Perfect Gift]: A Christmas wreath makes a perfect gift for friends, family, neighbors, housewarmings, farmhouses, and other .
[Artificial Christmas Wreath]: Decorated with red berries, and green leaves, it has a realistic visual effect, keeping your house full of life.
[Wide Application]: Holiday garland is perfect for decorating Christmas, Halloween, Thanksgiving, weddings, walls, doors, stages, bedrooms, offices, hotels, restaurants, gardens, balconies, fences, fireplaces, entryways, etc.
Package Includes:
1 Artificial Christmas Wreath
Note:
Please allow slightly errors due to manual measurement and different monitors.
info:
We aim to show you accurate product information. Manufacturers, suppliers and others provide what you see here, and we have not verified it.  See our disclaimer
## Specifications

Wreath type
Artificial Wreaths
Color
Green Red
Theme
Christmas
Occasion
Christmas
More details
## Warranty

Warranty information
Please be aware that the warranty terms on items offered for sale by third party Marketplace sellers may differ from those displayed in this section (if any). To confirm warranty terms on an item offered for sale by a third party Marketplace seller, please use the 'Contact seller' feature on the third party Marketplace seller's information page and request the item's warranty terms prior to purchase.
